@@ -15,11 +15,13 @@ import click
 
 from lean import __version__
 from lean.commands.backtest import backtest
+from lean.commands.build import build
 from lean.commands.cloud import cloud
 from lean.commands.config import config
 from lean.commands.create_project import create_project
 from lean.commands.data import data
 from lean.commands.init import init
+from lean.commands.library import library
 from lean.commands.live import live
 from lean.commands.login import login
 from lean.commands.logout import logout
@@ -40,6 +42,7 @@ def lean() -> None:
 lean.add_command(config)
 lean.add_command(cloud)
 lean.add_command(data)
+lean.add_command(library)
 
 lean.add_command(login)
 lean.add_command(logout)
@@ -50,3 +53,4 @@ lean.add_command(optimize)
 lean.add_command(research)
 lean.add_command(report)
 lean.add_command(live)
+lean.add_command(build)
