@@ -125,15 +125,14 @@ def live(project: str, push: bool, open_browser: bool) -> None:
     brokerage_settings = brokerage.get_settings(logger)
     price_data_handler = brokerage.get_price_data_handler()
 
-    organization = api_client.accounts.get_organization()
-    nodes = api_client.nodes.get_all(organization.organizationId)
+    nodes = api_client.nodes.get_all(cloud_project.organizationId)
 
     live_nodes = [node for node in nodes.live if not node.busy]
     if len(live_nodes) == 0:
         raise RuntimeError(
-            "You don't have any live nodes available, you can manage your nodes on https://www.quantconnect.com/terminal/#organization/resources")
+            f"You don't have any live nodes available, you can manage your nodes on https://www.quantconnect.com/organization/{cloud_project.organizationId}/resources")
 
-    node_options = [Option(id=node, label=f"{node.name} - {node.description}") for node in nodes.live]
+    node_options = [Option(id=node, label=f"{node.name} - {node.description}") for node in live_nodes]
     node: QCNode = logger.prompt_list("Select a node", node_options)
 
     logger.info(
