@@ -141,6 +141,16 @@ DEFAULT_CSHARP_NOTEBOOK = """
                 "<hr>"
             ]
         },
+        {
+            "cell_type": "code",
+            "execution_count": null,
+            "metadata": {},
+            "outputs": [],
+            "source": [
+                "// We need to load assemblies at the start in their own cell\\n",
+                "#load \\"../Initialize.csx\\""
+            ]
+        },
         {
             "cell_type": "code",
             "execution_count": null,
@@ -150,6 +160,12 @@ DEFAULT_CSHARP_NOTEBOOK = """
                 "// QuantBook C# Research Environment\\n",
                 "// For more information see https://www.quantconnect.com/docs/research/overview\\n",
                 "#load \\"../QuantConnect.csx\\"\\n",
+                "\\n",
+                "using QuantConnect;\\n",
+                "using QuantConnect.Data;\\n",
+                "using QuantConnect.Research;\\n",
+                "using QuantConnect.Algorithm;\\n",
+                "\\n",
                 "var qb = new QuantBook();\\n",
                 "var spy = qb.AddEquity(\\"SPY\\");\\n",
                 "var history = qb.History(qb.Securities.Keys, 360, Resolution.Daily);"
@@ -186,15 +202,6 @@ DEFAULT_CSHARP_NOTEBOOK = """
             "name": "C#",
             "pygments_lexer": "c#",
             "version": "4.0.30319"
-        },
-        "pycharm": {
-            "stem_cell": {
-                "cell_type": "raw",
-                "source": [],
-                "metadata": {
-                    "collapsed": false
-                }
-            }
         }
     },
     "nbformat": 4,
@@ -232,14 +239,13 @@ def create_project(name: str, language: str) -> None:
     if language is None:
         raise MoreInfoError(
             "Please specify a language with --language or set the default language using `lean config set default-language python/csharp`",
-            "https://www.quantconnect.com/docs/v2/lean-cli/tutorials/project-management")
+            "https://www.lean.io/docs/lean-cli/tutorials/project-management")
 
     full_path = Path.cwd() / name
 
-    path_validator = container.path_validator()
-    if not path_validator.is_path_valid(full_path):
+    if not container.path_manager().is_path_valid(full_path):
         raise MoreInfoError(f"'{name}' is not a valid path",
-                            "https://www.quantconnect.com/docs/v2/lean-cli/user-guides/troubleshooting#02-Common-errors")
+                            "https://www.lean.io/docs/lean-cli/user-guides/troubleshooting#02-Common-errors")
 
     if full_path.exists():
         raise RuntimeError(f"A project named '{name}' already exists, please choose a different name")
