@@ -12,7 +12,6 @@
 # limitations under the License.
 
 import shutil
-import tempfile
 import zipfile
 from pathlib import Path
 
@@ -78,7 +77,7 @@ def init() -> None:
         if path.exists():
             relative_path = path.relative_to(current_dir)
             raise MoreInfoError(f"{relative_path} already exists, please run this command in an empty directory",
-                                "https://www.quantconnect.com/docs/v2/lean-cli/user-guides/directory-structure#02-lean-init")
+                                "https://www.lean.io/docs/lean-cli/user-guides/directory-structure#02-lean-init")
 
     logger = container.logger()
 
@@ -88,7 +87,7 @@ def init() -> None:
         click.confirm("The current directory is not empty, continue?", default=False, abort=True)
 
     # Download the Lean repository
-    tmp_directory = Path(tempfile.mkdtemp())
+    tmp_directory = container.temp_manager().create_temporary_directory()
     _download_repository(tmp_directory / "master.zip")
 
     # Extract the downloaded repository
@@ -122,8 +121,8 @@ The following objects have been created:
 - {DEFAULT_DATA_DIRECTORY_NAME}/ contains the data that is used when running the LEAN engine locally
 
 The following documentation pages may be useful:
-- Setting up local autocomplete: https://www.quantconnect.com/docs/v2/lean-cli/tutorials/local-autocomplete
-- Synchronizing projects with the cloud: https://www.quantconnect.com/docs/v2/lean-cli/tutorials/cloud-synchronization
+- Setting up local autocomplete: https://www.lean.io/docs/lean-cli/tutorials/local-autocomplete
+- Synchronizing projects with the cloud: https://www.lean.io/docs/lean-cli/tutorials/cloud-synchronization
 
 Here are some commands to get you going:
 - Run `lean create-project "My Project"` to create a new project with starter code
