@@ -11,39 +11,53 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import tempfile
 import webbrowser
 from pathlib import Path
+from typing import Any, Dict, Optional
 
 import click
 from docker.errors import APIError
 from docker.types import Mount
 
 from lean.click import LeanCommand, PathParameter
-from lean.constants import RESEARCH_IMAGE
+from lean.constants import DEFAULT_RESEARCH_IMAGE
 from lean.container import container
 
 
-@click.command(cls=LeanCommand, requires_lean_config=True)
+def _check_docker_output(chunk: str, port: int) -> None:
+    """Checks the output of the Docker container and opens the browser if Jupyter Lab has started.
+
+    :param chunk: the output chunk
+    :param port: the port Jupyter Lab will be running on
+    """
+    if "is running at:" in chunk:
+        webbrowser.open(f"http://localhost:{port}/")
+
+
+@click.command(cls=LeanCommand, requires_lean_config=True, requires_docker=True)
 @click.argument("project", type=PathParameter(exists=True, file_okay=False, dir_okay=True))
 @click.option("--port", type=int, default=8888, help="The port to run Jupyter Lab on (defaults to 8888)")
+@click.option("--image",
+              type=str,
+              help=f"The LEAN research image to use (defaults to {DEFAULT_RESEARCH_IMAGE})")
 @click.option("--update",
               is_flag=True,
               default=False,
-              help="Pull the selected research environment version before starting it")
-@click.option("--version",
-              type=str,
-              default="latest",
-              help="The version of the research environment version to run (defaults to the latest installed version)")
-def research(project: Path, port: int, update: bool, version: str) -> None:
-    """Run a Jupyter Lab environment locally using Docker."""
+              help="Pull the LEAN research image before starting the research environment")
+def research(project: Path, port: int, image: Optional[str], update: bool) -> None:
+    """Run a Jupyter Lab environment locally using Docker.
+
+    By default the official LEAN research image is used.
+    You can override this using the --image option.
+    Alternatively you can set the default research image using `lean config set research-image <image>`.
+    """
     cli_config_manager = container.cli_config_manager()
 
     project_config_manager = container.project_config_manager()
     project_config = project_config_manager.get_project_config(project)
 
     # Copy the config to a temporary config file before we add some research-specific configuration to it
-    config_path = Path(tempfile.mkdtemp()) / "config.json"
+    config_path = container.temp_manager().create_temporary_directory() / "config.json"
     project_config.file = config_path
 
     project_config.set("composer-dll-directory", "/Lean/Launcher/bin/Debug")
@@ -56,7 +70,9 @@ def research(project: Path, port: int, update: bool, version: str) -> None:
     lean_config_manager = container.lean_config_manager()
     data_dir = lean_config_manager.get_data_directory()
 
-    run_options = {
+    run_options: Dict[str, Any] = {
+        "commands": [],
+        "environment": {},
         "mounts": [
             Mount(target="/Lean/Launcher/bin/Debug/Notebooks/config.json",
                   source=str(config_path),
@@ -67,35 +83,48 @@ def research(project: Path, port: int, update: bool, version: str) -> None:
             str(data_dir): {
                 "bind": "/Lean/Launcher/Data",
                 "mode": "rw"
-            },
-            str(project): {
-                "bind": "/Lean/Launcher/bin/Debug/Notebooks",
-                "mode": "rw"
             }
         },
         "ports": {
             "8888": str(port)
         },
-        "on_run": lambda: webbrowser.open(f"http://localhost:{port}/")
+        "on_output": lambda chunk: _check_docker_output(chunk, port)
     }
 
+    lean_runner = container.lean_runner()
+    if project_config.get("algorithm-language", "Python") == "Python":
+        lean_runner.set_up_python_options(project, "/Lean/Launcher/bin/Debug/Notebooks", run_options)
+    else:
+        lean_runner.set_up_csharp_options(project, run_options)
+        run_options["volumes"][str(project)] = {
+            "bind": "/Lean/Launcher/bin/Debug/Notebooks",
+            "mode": "rw"
+        }
+
+    # Add references to all DLLs in QuantConnect.csx so custom C# libraries can be imported with using statements
+    run_options["commands"].append(" && ".join([
+        'find . -maxdepth 1 -iname "*.dll" | xargs -I _ echo \'#r "_"\' | cat - QuantConnect.csx > NewQuantConnect.csx',
+        "mv NewQuantConnect.csx QuantConnect.csx"
+    ]))
+
+    # Run the script that starts Jupyter Lab when all set up has been done
+    run_options["commands"].append("./start.sh")
+
+    cli_config_manager = container.cli_config_manager()
+    research_image = cli_config_manager.get_research_image(image)
+
     docker_manager = container.docker_manager()
 
-    if version != "latest":
-        if not docker_manager.tag_exists(RESEARCH_IMAGE, version):
-            raise RuntimeError(
-                f"The specified version does not exist, please pick a valid tag from https://hub.docker.com/r/{RESEARCH_IMAGE}/tags")
+    if update or not docker_manager.supports_dotnet_5(research_image):
+        docker_manager.pull_image(research_image)
 
-    if update:
-        docker_manager.pull_image(RESEARCH_IMAGE, version)
-
-    if version == "latest" and not update:
+    if str(research_image) == DEFAULT_RESEARCH_IMAGE and not update:
         update_manager = container.update_manager()
-        update_manager.warn_if_docker_image_outdated(RESEARCH_IMAGE)
+        update_manager.warn_if_docker_image_outdated(research_image)
 
     try:
-        docker_manager.run_image(RESEARCH_IMAGE, version, **run_options)
+        docker_manager.run_image(research_image, **run_options)
     except APIError as error:
         if "port is already allocated" in error.explanation:
-            raise RuntimeError(f"Port {port} is already in use, please specify a different port using --port")
+            raise RuntimeError(f"Port {port} is already in use, please specify a different port using --port <number>")
         raise error
