@@ -15,7 +15,7 @@ import re
 from pathlib import Path
 from typing import Any, Dict, Optional
 
-from jsoncomment import JsonComment
+import json5
 
 from lean.components.config.cli_config_manager import CLIConfigManager
 from lean.components.config.project_config_manager import ProjectConfigManager
@@ -60,7 +60,7 @@ class LeanConfigManager:
             # If the parent directory is the same as the current directory we can't go up any more
             if current_dir.parent == current_dir:
                 raise MoreInfoError(f"'{DEFAULT_LEAN_CONFIG_FILE_NAME}' not found",
-                                    "https://www.quantconnect.com/docs/v2/lean-cli/user-guides/configuration#03-Lean-configuration")
+                                    "https://www.lean.io/docs/lean-cli/user-guides/configuration#03-Lean-configuration")
 
             current_dir = current_dir.parent
 
@@ -83,9 +83,31 @@ class LeanConfigManager:
 
         :return: the path to the data directory as it is configured in the Lean config
         """
-        config = self._read_lean_config()
+        config = self.get_lean_config()
         return self.get_cli_root_directory() / config["data-folder"]
 
+    def set_property(self, key: str, value: str) -> None:
+        """Sets a string property in the Lean config file.
+
+        If the property does not exist yet it is added automatically.
+        Comments in the Lean config file are preserved.
+
+        :param key: the key of the property to update
+        :param value: the new value of the property
+        """
+        config = self.get_lean_config()
+
+        config_path = self.get_lean_config_path()
+        config_text = config_path.read_text(encoding="utf-8")
+
+        # We can only use regex to set the property because converting the config back to JSON drops all comments
+        if key in config:
+            config_text = re.sub(fr'"{key}":\s*"([^"]*)"', f'"{key}": "{value}"', config_text)
+        else:
+            config_text = config_text.replace("{", f'{{\n  "{key}": "{value}",', 1)
+
+        config_path.write_text(config_text, encoding="utf-8")
+
     def clean_lean_config(self, config: str) -> str:
         """Removes the properties from a Lean config file which can be set in get_complete_lean_config().
 
@@ -152,15 +174,19 @@ class LeanConfigManager:
         :param algorithm_file: the path to the algorithm that will be ran
         :param debugging_method: the debugging method to use, or None to disable debugging
         """
-        config = self._read_lean_config()
+        config = self.get_lean_config()
 
         config["environment"] = environment
         config["close-automatically"] = True
 
         config["composer-dll-directory"] = "."
 
-        config["debugging"] = debugging_method is not None and debugging_method != DebuggingMethod.Mono
-        config["debugging-method"] = debugging_method.value if debugging_method is not None else "LocalCmdline"
+        if debugging_method is not None:
+            config["debugging"] = True
+            config["debugging-method"] = debugging_method.get_internal_name()
+        else:
+            config["debugging"] = False
+            config["debugging-method"] = "LocalCmdline"
 
         config["job-user-id"] = self._cli_config_manager.user_id.get_value(default="0")
         config["api-access-token"] = self._cli_config_manager.api_token.get_value(default="")
@@ -187,14 +213,9 @@ class LeanConfigManager:
 
         return config
 
-    def _read_lean_config(self) -> Dict[str, Any]:
+    def get_lean_config(self) -> Dict[str, Any]:
         """Reads the Lean config into a dict.
 
         :return: a dict containing the contents of the Lean config file
         """
-        config_text = self.get_lean_config_path().read_text(encoding="utf-8")
-
-        # JsonComment can parse JSON with non-inline comments, so we remove the inline ones first
-        config_without_inline_comments = re.sub(r",\s*//.*", ",", config_text, flags=re.MULTILINE)
-
-        return JsonComment().loads(config_without_inline_comments)
+        return json5.loads(self.get_lean_config_path().read_text(encoding="utf-8"))
