@@ -18,21 +18,25 @@ import sys
 from datetime import datetime, timezone
 from pathlib import Path
 from typing import List
-from xml.etree import ElementTree
+
+import pkg_resources
 
 from lean.components.config.project_config_manager import ProjectConfigManager
+from lean.components.util.xml_manager import XMLManager
 from lean.models.api import QCLanguage, QCProject
 
 
 class ProjectManager:
     """The ProjectManager class provides utilities for handling a single project."""
 
-    def __init__(self, project_config_manager: ProjectConfigManager) -> None:
+    def __init__(self, project_config_manager: ProjectConfigManager, xml_manager: XMLManager) -> None:
         """Creates a new ProjectManager instance.
 
         :param project_config_manager: the ProjectConfigManager to use when creating new projects
+        :param xml_manager: the XMLManager to use when working with XML
         """
         self._project_config_manager = project_config_manager
+        self._xml_manager = xml_manager
 
     def find_algorithm_file(self, input: Path) -> Path:
         """Returns the path to the file containing the algorithm.
@@ -129,7 +133,7 @@ class ProjectManager:
         else:
             self._generate_vscode_csharp_config(project_dir)
             self._generate_csproj(project_dir)
-            self._generate_rider_config(project_dir)
+            self.generate_rider_config()
 
     def _generate_vscode_python_config(self, project_dir: Path) -> None:
         """Generates Python interpreter configuration and Python debugging configuration for VS Code.
@@ -156,7 +160,7 @@ class ProjectManager:
             "pathMappings": [
                 {
                     "localRoot": "${workspaceFolder}",
-                    "remoteRoot": "/LeanCLI"
+                    "remoteRoot": "/Lean/Launcher/bin/Debug"
                 }
             ]
         }
@@ -213,7 +217,7 @@ class ProjectManager:
       <PathMappingSettings>
         <option name="pathMappings">
           <list>
-            <mapping local-root="$PROJECT_DIR$" remote-root="/LeanCLI" />
+            <mapping local-root="$PROJECT_DIR$" remote-root="/Lean/Launcher/bin/Debug" />
           </list>
         </option>
       </PathMappingSettings>
@@ -229,7 +233,7 @@ class ProjectManager:
         """)
 
     def _generate_pycharm_jdk_entry(self, editor_name: str) -> None:
-        """Generates a "LeanCLI" Python JDK entry to PyCharm's internal JDK table.
+        """Generates a "Lean CLI" Python JDK entry to PyCharm's internal JDK table.
 
         When we generate PyCharm's .idea directory we want to tell PyCharm where the Python interpreter is located.
         PyCharm stores this bit of configuration globally, so we find the global location and update it to our needs.
@@ -239,38 +243,21 @@ class ProjectManager:
 
         :param editor_name: the name of the JetBrains editor, like PyCharm or PyCharmCE
         """
-        # Find JetBrains' global config directory
-        # See https://www.jetbrains.com/help/pycharm/project-and-ide-settings.html#ide_settings
-        if platform.system() == "Windows":
-            # Windows
-            jetbrains_config_dir = Path("~/AppData/Roaming/JetBrains").expanduser()
-        elif platform.system() == "Darwin":
-            # macOS
-            jetbrains_config_dir = Path("~/Library/Application Support/JetBrains").expanduser()
-        else:
-            # Linux
-            jetbrains_config_dir = Path("~/.config/JetBrains").expanduser()
-
-        # Find PyCharm's global config directory
-        pycharm_config_dirs = sorted(p for p in jetbrains_config_dir.glob(f"{editor_name}*"))
-        if len(pycharm_config_dirs) > 0:
-            pycharm_config_dir = pycharm_config_dirs[-1]
-        else:
-            pycharm_config_dir = jetbrains_config_dir / editor_name
+        pycharm_config_dir = self._get_jetbrains_config_dir(editor_name)
 
         # Parse the file containing PyCharm's internal table of Python interpreters
         jdk_table_file = pycharm_config_dir / "options" / "jdk.table.xml"
         if jdk_table_file.exists():
-            root = ElementTree.fromstring(jdk_table_file.read_text(encoding="utf-8"))
+            root = self._xml_manager.parse(jdk_table_file.read_text(encoding="utf-8"))
         else:
-            root = ElementTree.fromstring("""
+            root = self._xml_manager.parse("""
 <application>
   <component name="ProjectJdkTable">
   </component>
 </application>
             """)
 
-        # Don't do anything if the LeanCLI interpreter entry already exists
+        # Don't do anything if the Lean CLI interpreter entry already exists
         if root.find(".//jdk/name[@value='Lean CLI']") is not None:
             return
 
@@ -280,7 +267,7 @@ class ProjectManager:
         classpath_entries = "\n".join(classpath_entries)
 
         component_element = root.find(".//component[@name='ProjectJdkTable']")
-        component_element.append(ElementTree.fromstring(f"""
+        component_element.append(self._xml_manager.parse(f"""
 <jdk version="2">
   <name value="Lean CLI" />
   <type value="Python SDK" />
@@ -305,7 +292,7 @@ class ProjectManager:
         """))
 
         # Save the modified XML tree
-        self._generate_file(jdk_table_file, ElementTree.tostring(root, encoding="utf-8", method="xml").decode("utf-8"))
+        self._generate_file(jdk_table_file, self._xml_manager.to_string(root))
 
     def _generate_vscode_csharp_config(self, project_dir: Path) -> None:
         """Generates C# debugging configuration for VS Code.
@@ -319,9 +306,18 @@ class ProjectManager:
         {
             "name": "Debug with Lean CLI",
             "request": "attach",
-            "type": "mono",
-            "address": "localhost",
-            "port": 55556
+            "type": "coreclr",
+            "processId": "${command:pickRemoteProcess}",
+            "pipeTransport": {
+                "pipeCwd": "${workspaceRoot}",
+                "pipeProgram": "docker",
+                "pipeArgs": ["exec", "-i", "lean_cli_vsdbg"],
+                "debuggerPath": "/root/vsdbg/vsdbg",
+                "quoteArgs": false
+            },
+            "logging": {
+                "moduleLoad": false
+            }
         }
     ]
 }
@@ -333,90 +329,78 @@ class ProjectManager:
         :param project_dir: the path of the new project
         """
         self._generate_file(project_dir / f"{project_dir.name}.csproj", """
-<!--
-This file exists to make C# autocomplete and debugging work.
-
-Custom libraries added in this file won't be used when compiling your code.
-When using the Lean CLI to run algorithms, this csproj file is overwritten
-to make your code compile against all the DLLs in the QuantConnect/Lean
-Docker container. This container contains the following libraries besides
-the System.* and QuantConnect.* libraries:
-https://www.quantconnect.com/docs/key-concepts/supported-libraries
-
-If you want to get autocomplete to work for any of the C# libraries listed
-on the page above, you can add a PackageReference for it.
--->
 <Project Sdk="Microsoft.NET.Sdk">
     <PropertyGroup>
         <Configuration Condition=" '$(Configuration)' == '' ">Debug</Configuration>
         <Platform Condition=" '$(Platform)' == '' ">AnyCPU</Platform>
-        <TargetFramework>net462</TargetFramework>
-        <LangVersion>6</LangVersion>
+        <TargetFramework>net5.0</TargetFramework>
+        <LangVersion>9</LangVersion>
         <OutputPath>bin/$(Configuration)</OutputPath>
         <AppendTargetFrameworkToOutputPath>false</AppendTargetFrameworkToOutputPath>
+        <NoWarn>CS0618</NoWarn>
     </PropertyGroup>
-     <PropertyGroup>
-        <IsWindows>false</IsWindows>
-        <IsWindows Condition="'$(OS)' == 'Windows_NT'">true</IsWindows>
-        <IsOSX>false</IsOSX>
-        <IsOSX Condition="'$(IsWindows)' != 'true' AND '$([System.Runtime.InteropServices.RuntimeInformation]::IsOSPlatform($([System.Runtime.InteropServices.OSPlatform]::OSX)))' == 'true'">true</IsOSX>
-        <IsLinux>false</IsLinux>
-        <IsLinux Condition="'$(IsWindows)' != 'true' AND '$(IsOSX)' != 'true' AND '$([System.Runtime.InteropServices.RuntimeInformation]::IsOSPlatform($([System.Runtime.InteropServices.OSPlatform]::Linux)))' == 'true'">true</IsLinux>
-    </PropertyGroup>
-    <Choose>
-        <When Condition="$(IsWindows)">
-            <ItemGroup>
-                <Reference Include="Python.Runtime, Version=1.0.5.30, Culture=neutral, processorArchitecture=MSIL">
-                    <HintPath>$(NuGetPackageRoot)/quantconnect.pythonnet/1.0.5.30/lib/win/Python.Runtime.dll</HintPath>
-                </Reference>
-            </ItemGroup>
-        </When>
-        <When Condition="$(IsLinux)">
-            <ItemGroup>
-                <Reference Include="Python.Runtime, Version=1.0.5.30, Culture=neutral, processorArchitecture=MSIL">
-                    <HintPath>$(NuGetPackageRoot)/quantconnect.pythonnet/1.0.5.30/lib/linux/Python.Runtime.dll</HintPath>
-                </Reference>
-            </ItemGroup>
-        </When>
-        <When Condition="$(IsOSX)">
-            <ItemGroup>
-                <Reference Include="Python.Runtime, Version=1.0.5.30, Culture=neutral, processorArchitecture=MSIL">
-                    <HintPath>$(NuGetPackageRoot)/quantconnect.pythonnet/1.0.5.30/lib/osx/Python.Runtime.dll</HintPath>
-                </Reference>
-            </ItemGroup>
-        </When>
-    </Choose>
     <ItemGroup>
-        <PackageReference Include="QuantConnect.Lean" Version="2.5.11072"/>
+        <PackageReference Include="QuantConnect.Lean" Version="2.5.11586"/>
     </ItemGroup>
 </Project>
         """)
 
-    def _generate_rider_config(self, project_dir: Path) -> None:
-        """Generates C# debugging configuration for Rider.
+    def generate_rider_config(self) -> None:
+        """Generates C# debugging configuration for Rider."""
+        ssh_dir = Path("~/.lean/ssh").expanduser()
 
-        :param project_dir: the directory of the new project
-        """
-        workspace_xml = """
-<?xml version="1.0" encoding="UTF-8"?>
-<project version="4">
-  <component name="RunManager">
-    <configuration name="Debug with Lean CLI" type="ConnectRemote" factoryName="Mono Remote" show_console_on_std_err="false" show_console_on_std_out="false" port="55556" address="localhost">
-      <option name="allowRunningInParallel" value="false" />
-      <option name="listenPortForConnections" value="false" />
-      <option name="selectedOptions">
-        <list />
-      </option>
-      <method v="2" />
-    </configuration>
-  </component>
-</project>
-        """
+        # Add SSH keys to .lean/ssh if necessary
+        if not ssh_dir.exists():
+            ssh_dir.mkdir(parents=True)
+            for name in ["key", "key.pub", "README.md"]:
+                with (ssh_dir / name).open("wb+") as file:
+                    file.write(pkg_resources.resource_string("lean", f"ssh/{name}"))
 
-        self._generate_file(project_dir / ".idea" / f".idea.{project_dir.name}" / ".idea" / "workspace.xml",
-                            workspace_xml)
-        self._generate_file(project_dir / ".idea" / f".idea.{project_dir.name}.dir" / ".idea" / "workspace.xml",
-                            workspace_xml)
+        # Find Rider's global configuration directory
+        rider_config_dir = self._get_jetbrains_config_dir("Rider")
+
+        # Parse the file containing Rider's internal list of remote hosts
+        debugger_file = rider_config_dir / "options" / "debugger.xml"
+        if debugger_file.exists():
+            root = self._xml_manager.parse(debugger_file.read_text(encoding="utf-8"))
+        else:
+            root = self._xml_manager.parse("""
+<application>
+    <component name="XDebuggerSettings">
+    </component>
+</application>
+            """)
+
+        component_element = root.find(".//component[@name='XDebuggerSettings']")
+
+        if root.find(".//debuggers") is None:
+            component_element.append(self._xml_manager.parse("<debuggers></debuggers>"))
+        debuggers = root.find(".//debuggers")
+
+        if debuggers.find(".//debugger[@id='dotnet_debugger']") is None:
+            debuggers.append(self._xml_manager.parse('<debugger id="dotnet_debugger"></debugger>'))
+        dotnet_debugger = debuggers.find(".//debugger[@id='dotnet_debugger']")
+
+        if dotnet_debugger.find(".//configuration") is None:
+            dotnet_debugger.append(self._xml_manager.parse("<configuration></configuration>"))
+        configuration = dotnet_debugger.find(".//configuration")
+
+        if configuration.find(".//option[@name='sshCredentials']") is None:
+            configuration.append(self._xml_manager.parse('<option name="sshCredentials"></option>'))
+        ssh_credentials = configuration.find(".//option[@name='sshCredentials']")
+
+        required_value = f"&lt;credentials HOST=&quot;localhost&quot; PORT=&quot;2222&quot; USERNAME=&quot;root&quot; PRIVATE_KEY_FILE=&quot;{ssh_dir.as_posix()}/key&quot; USE_KEY_PAIR=&quot;true&quot; USE_AUTH_AGENT=&quot;false&quot; /&gt;"
+
+        # Don't do anything if the required entry already exists
+        for option in ssh_credentials.findall(f".//option"):
+            if option.get("value") == required_value.replace("&lt;", "<").replace("&gt;", ">").replace("&quot;", '"'):
+                return
+
+        # Add the new entry to the XML tree
+        ssh_credentials.append(self._xml_manager.parse(f'<option value="{required_value}"/>'))
+
+        # Save the modified XML tree
+        self._generate_file(debugger_file, self._xml_manager.to_string(root))
 
     def _generate_file(self, file: Path, content: str) -> None:
         """Writes to a file, which is created if it doesn't exist yet, and normalized the content before doing so.
@@ -427,3 +411,25 @@ on the page above, you can add a PackageReference for it.
         file.parent.mkdir(parents=True, exist_ok=True)
         with file.open("w+", encoding="utf-8") as file:
             file.write(content.strip() + "\n")
+
+    def _get_jetbrains_config_dir(self, editor_name: str) -> Path:
+        """Returns the path to the global configuration directory of a JetBrains IDE.
+
+        :param editor_name: the name of the JetBrains IDE
+        :return: the path to the directory holding the global configuration for the specified IDE
+        """
+        # Find JetBrains' global config directory
+        # See https://www.jetbrains.com/help/pycharm/project-and-ide-settings.html#ide_settings
+        if platform.system() == "Windows":
+            jetbrains_config_dir = Path("~/AppData/Roaming/JetBrains").expanduser()
+        elif platform.system() == "Darwin":
+            jetbrains_config_dir = Path("~/Library/Application Support/JetBrains").expanduser()
+        else:
+            jetbrains_config_dir = Path("~/.config/JetBrains").expanduser()
+
+        # Find the global config directory for the given editor
+        config_dirs = sorted(p for p in jetbrains_config_dir.glob(f"{editor_name}*"))
+        if len(config_dirs) > 0:
+            return config_dirs[-1]
+        else:
+            return jetbrains_config_dir / editor_name
