@@ -11,6 +11,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from datetime import datetime, timezone
 from pathlib import Path
 
 # Due to the way the filesystem is mocked in unit tests, values should not be Path instances.
@@ -21,6 +22,7 @@ GENERAL_CONFIG_PATH = str(Path("~/.lean/config").expanduser())
 # The file in which credentials are stored
 CREDENTIALS_CONFIG_PATH = str(Path("~/.lean/credentials").expanduser())
 
+# The file in which we store when we last checked for updates
 CACHE_PATH = str(Path("~/.lean/cache").expanduser())
 
 # The default name of the file containing the Lean engine configuration
@@ -32,11 +34,20 @@ DEFAULT_DATA_DIRECTORY_NAME = "data"
 # The name of the file in containing the project configuration
 PROJECT_CONFIG_FILE_NAME = "config.json"
 
-# The Docker image used when running the LEAN engine locally
-ENGINE_IMAGE = "quantconnect/lean"
+# The default Docker image used when running the LEAN engine locally
+DEFAULT_ENGINE_IMAGE = "quantconnect/lean:latest"
 
-# The Docker image used when running a Jupyter Lab environment locally
-RESEARCH_IMAGE = "quantconnect/research"
+# The default Docker image used when running a Jupyter Lab environment locally
+DEFAULT_RESEARCH_IMAGE = "quantconnect/research:latest"
+
+# The creation timestamp of the first image supporting .NET 5
+DOTNET_5_IMAGE_CREATED_TIMESTAMP = datetime(2021, 5, 6, 21, 32, 26, tzinfo=timezone.utc)
+
+# When we install custom Python libraries, we first mount a volume to the user site packages directory
+# This caches the installation and makes subsequent backtests much faster
+# Because the site packages are not versioned, we cannot reuse the volume between algorithms with different requirements
+# This constant defines how many site packages volumes get created before old ones are removed
+SITE_PACKAGES_VOLUME_LIMIT = 10
 
 # The base url of the QuantConnect API
 # This url should end with a forward slash
