@@ -25,16 +25,16 @@ from lean.components.config.lean_config_manager import LeanConfigManager
 from lean.components.config.optimizer_config_manager import OptimizerConfigManager
 from lean.components.config.project_config_manager import ProjectConfigManager
 from lean.components.config.storage import Storage
-from lean.components.docker.csharp_compiler import CSharpCompiler
 from lean.components.docker.docker_manager import DockerManager
 from lean.components.docker.lean_runner import LeanRunner
 from lean.components.util.logger import Logger
-from lean.components.util.market_hours_database import MarketHoursDatabase
 from lean.components.util.name_generator import NameGenerator
-from lean.components.util.path_validator import PathValidator
+from lean.components.util.path_manager import PathManager
 from lean.components.util.project_manager import ProjectManager
 from lean.components.util.task_manager import TaskManager
+from lean.components.util.temp_manager import TempManager
 from lean.components.util.update_manager import UpdateManager
+from lean.components.util.xml_manager import XMLManager
 from lean.constants import CACHE_PATH, CREDENTIALS_CONFIG_PATH, GENERAL_CONFIG_PATH
 
 
@@ -44,20 +44,20 @@ class Container(DeclarativeContainer):
 
     task_manager = Singleton(TaskManager, logger)
     name_generator = Singleton(NameGenerator)
-    path_validator = Singleton(PathValidator)
+    path_manager = Singleton(PathManager)
+    temp_manager = Singleton(TempManager)
+    xml_manager = Singleton(XMLManager)
 
     general_storage = Singleton(Storage, file=GENERAL_CONFIG_PATH)
     credentials_storage = Singleton(Storage, file=CREDENTIALS_CONFIG_PATH)
     cache_storage = Singleton(Storage, file=CACHE_PATH)
 
-    project_config_manager = Singleton(ProjectConfigManager)
+    project_config_manager = Singleton(ProjectConfigManager, xml_manager)
     cli_config_manager = Singleton(CLIConfigManager, general_storage, credentials_storage)
     lean_config_manager = Singleton(LeanConfigManager, cli_config_manager, project_config_manager)
     optimizer_config_manager = Singleton(OptimizerConfigManager, logger)
 
-    project_manager = Singleton(ProjectManager, project_config_manager)
-
-    market_hours_database = Singleton(MarketHoursDatabase, lean_config_manager)
+    project_manager = Singleton(ProjectManager, project_config_manager, xml_manager)
 
     api_client = Factory(APIClient,
                          logger,
@@ -67,18 +67,22 @@ class Container(DeclarativeContainer):
     cloud_runner = Singleton(CloudRunner, logger, api_client, task_manager)
     pull_manager = Singleton(PullManager, logger, api_client, project_manager, project_config_manager)
     push_manager = Singleton(PushManager, logger, api_client, project_manager, project_config_manager)
-    data_downloader = Singleton(DataDownloader, logger, api_client, lean_config_manager, market_hours_database)
+    data_downloader = Singleton(DataDownloader, logger, api_client, lean_config_manager)
     cloud_project_manager = Singleton(CloudProjectManager,
                                       api_client,
                                       project_config_manager,
                                       pull_manager,
                                       push_manager,
-                                      path_validator)
+                                      path_manager)
 
-    docker_manager = Singleton(DockerManager, logger)
+    docker_manager = Singleton(DockerManager, logger, temp_manager)
 
-    csharp_compiler = Singleton(CSharpCompiler, logger, docker_manager)
-    lean_runner = Singleton(LeanRunner, logger, csharp_compiler, lean_config_manager, docker_manager)
+    lean_runner = Singleton(LeanRunner,
+                            logger,
+                            project_config_manager,
+                            lean_config_manager,
+                            docker_manager,
+                            temp_manager)
 
     update_manager = Singleton(UpdateManager, logger, cache_storage, docker_manager)
 
