@@ -11,6 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
+import platform
+import site
+
+# This code has to run before Docker is imported anywhere in the code
+if platform.system() == "Windows":
+    for site_packages_path in site.getsitepackages() + [site.getusersitepackages()]:
+        os.environ["PATH"] += ";" + os.path.join(site_packages_path, "pywin32_system32")
+
 import sys
 import traceback
 from io import StringIO
@@ -28,6 +37,7 @@ def main() -> None:
     """This function is the entrypoint when running a Lean command in a terminal."""
     try:
         lean.main(standalone_mode=False)
+        container.temp_manager().delete_temporary_directories()
     except Exception as exception:
         logger = container.logger()
         logger.debug(traceback.format_exc().strip())
@@ -46,7 +56,7 @@ def main() -> None:
             exception_str = io.getvalue().strip()
             exception_str = exception_str.replace("Try 'lean", "\nTry 'lean")
             exception_str = exception_str.replace("for help.",
-                                                  "for help or go to the following url for a list of common errors:\nhttps://www.quantconnect.com/docs/v2/lean-cli/user-guides/troubleshooting")
+                                                  "for help or go to the following url for a list of common errors:\nhttps://www.lean.io/docs/lean-cli/user-guides/troubleshooting")
 
             logger.info(exception_str)
         elif isinstance(exception, click.Abort):
@@ -57,4 +67,5 @@ def main() -> None:
         else:
             logger.error(f"Error: {exception}")
 
+        container.temp_manager().delete_temporary_directories()
         sys.exit(1)
