@@ -11,6 +11,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import re
 from datetime import datetime
 from enum import Enum
 from typing import Any, Dict, List, Optional, Union
@@ -99,7 +100,7 @@ class QCProject(WrappedBaseModel):
 
         :return: a url which when visited opens an Algorithm Lab tab containing the project
         """
-        return f"https://www.quantconnect.com/terminal/#open/{self.projectId}"
+        return f"https://www.quantconnect.com/project/{self.projectId}"
 
 
 class QCCreatedProject(WrappedBaseModel):
@@ -305,11 +306,78 @@ class QCCard(WrappedBaseModel):
     last4: str
 
 
-class QCOrganization(WrappedBaseModel):
+class QCAccount(WrappedBaseModel):
     organizationId: str
-    creditBalance: float
     card: Optional[QCCard] = None
 
+    # Balance in QCC
+    creditBalance: float
+
+
+class QCOrganizationCreditMovement(WrappedBaseModel):
+    date: str
+    description: str
+    type: str
+    subtype: str
+    amount: float
+
+    # Balance in QCC
+    balance: float
+
+
+class QCOrganizationCredit(WrappedBaseModel):
+    movements: List[QCOrganizationCreditMovement]
+
+    # Balance in QCC
+    balance: float
+
+
+class QCOrganizationProductItem(WrappedBaseModel):
+    name: str
+    quantity: int
+    unitPrice: float
+    total: float
+
+
+class QCOrganizationProduct(WrappedBaseModel):
+    name: str
+    items: List[QCOrganizationProductItem]
+
+
+class QCOrganizationData(WrappedBaseModel):
+    signedTime: Optional[int]
+    current: bool
+
+
+class QCFullOrganization(WrappedBaseModel):
+    id: str
+    name: str
+    seats: int
+    type: str
+    credit: QCOrganizationCredit
+    products: List[QCOrganizationProduct]
+    data: QCOrganizationData
+
+    def has_map_factor_files_subscription(self) -> bool:
+        """Returns whether this organization has a map & factor files subscription.
+
+        :return: True if the organization has a map & factor files subscription, False if not
+        """
+        data_products_product = next((x for x in self.products if x.name == "Data"), None)
+        if data_products_product is None:
+            return False
+
+        return any(x.name == "QuantConnect Equity Factor & Map Files" for x in data_products_product.items)
+
+
+class QCMinimalOrganization(WrappedBaseModel):
+    id: str
+    name: str
+    type: str
+    ownerName: str
+    members: int
+    preferred: bool
+
 
 class QCSecurityType(str, Enum):
     Equity = "Equity"
@@ -386,3 +454,22 @@ class QCOptimizationEstimate(WrappedBaseModel):
     estimateId: str
     time: int
     balance: int
+
+
+class QCDataVendor(WrappedBaseModel):
+    vendorName: str
+    regex: Any
+
+    # Price in QCC
+    price: Optional[float]
+
+    @validator("regex", pre=True)
+    def parse_regex(cls, value: Any) -> Any:
+        if isinstance(value, str):
+            return re.compile(value[value.index("/") + 1:value.rindex("/")])
+        return value
+
+
+class QCDataInformation(WrappedBaseModel):
+    prices: List[QCDataVendor]
+    agreement: str
